/* xkeycaps, Copyright (c) 1991, 1992, 1993 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of the NCD X terminal N97 keyboard.
 */

static const KeyCode ncd97_codes [] = {

  /* Row 0 */
  16, 15, 23, 31,
  39, 47, 55, 63,
  71, 79, 86, 94,
  95, 0,

  /* Row 2 */
  8, 22, 30, 38, 37, 46, 54, 61, 62, 70, 69, 78, 85, 14, 102,
  118, 119, 126, 124,

  /* Row 3 */
  13, 21, 29, 36, 45, 44, 53, 60, 67, 68, 77, 84, 91, 92, 100,
  108, 117, 125, 132,
  
  /* Row 4 */
  17, 28, 27, 35, 43, 52, 51, 59, 66, 75, 76, 82, 90, 87,
  107, 115, 116, 109,

  /* Row 5 */
  18, 26, 34, 33, 42, 50, 49, 58, 65, 73, 74, 89, 99, 88,
  105, 114, 122, 121,
  
  /* Row 6 */
  20, 25, 41, 57, 97, 96, 106,
  112, 113
};
